@@ -24,11 +24,14 @@
 #include "mtx/events/voip.hpp"
 
 #include "mtx/events/messages/audio.hpp"
+#include "mtx/events/messages/elementeffect.hpp"
 #include "mtx/events/messages/emote.hpp"
 #include "mtx/events/messages/file.hpp"
 #include "mtx/events/messages/image.hpp"
+#include "mtx/events/messages/location.hpp"
 #include "mtx/events/messages/notice.hpp"
 #include "mtx/events/messages/text.hpp"
+#include "mtx/events/messages/unknown.hpp"
 #include "mtx/events/messages/video.hpp"
 
 #include "mtx/user_interactive.hpp"
