@@ -3,6 +3,8 @@
 /// @file
 /// @brief The error struct returned by the Matrix API.
 
+#include <chrono>
+
 #include "lightweight_error.hpp"
 #include "user_interactive.hpp"
 
@@ -19,6 +21,9 @@ struct Error
     //! Auth flows in case of 401
     user_interactive::Unauthorized unauthorized;
 
+    //! Retry delay in case of 429
+    std::chrono::duration<std::uint64_t, std::milli> retry_after;
+
     friend void from_json(const nlohmann::json &obj, Error &error);
 };
 }
