@@ -31,6 +31,9 @@ struct Emote
     //! Relates to for rich replies
     mtx::common::Relations relations;
 
+    //! Mentioned users by this event
+    std::optional<mtx::common::Mentions> mentions;
+
     friend void from_json(const nlohmann::json &obj, Emote &content);
     friend void to_json(nlohmann::json &obj, const Emote &content);
 };
